@@ -38,11 +38,17 @@ SEXP openxlsx2_type(SEXP x) {
       z = VECTOR_ELT(x, i);
     }
 
+    SEXP Rclass = Rf_getAttrib(z, R_ClassSymbol);
+
     switch (TYPEOF(z)) {
 
     // logical
     case LGLSXP:
-      type[i] =  3;
+      if (Rf_isNull(Rclass)) {
+        type[i] = 3; // logical
+      } else {
+        type[i] = 12; // probably some custom class
+      };
       break;
 
       // character, formula, hyperlink, array_formula
@@ -54,6 +60,8 @@ SEXP openxlsx2_type(SEXP x) {
         type[i] = 10;
       } else if (Rf_inherits(z, "array_formula")) {
         type[i] = 11;
+      } else if (Rf_inherits(z, "cm_formula")) {
+        type[i] = 14;
       } else {
         type[i] = 4;
       }
@@ -78,8 +86,14 @@ SEXP openxlsx2_type(SEXP x) {
       type[i] = 9;
     } else if (Rf_inherits(z, "factor")) {
       type[i] = 12;
+    } else if (Rf_inherits(z, "hms")) {
+      type[i] = 15;
     } else {
-      type[i] = 2; // numeric or integer
+      if (Rf_isNull(Rclass)) {
+        type[i] = 2; // numeric and integer
+      } else {
+        type[i] = 12; // probably some custom class
+      }
     }
     break;
 
@@ -310,7 +324,8 @@ void wide_to_long(
     bool na_null,
     bool na_missing,
     std::string na_strings,
-    bool inline_strings
+    bool inline_strings,
+    std::string c_cm
 ) {
 
   auto n = z.nrow();
@@ -321,6 +336,7 @@ void wide_to_long(
   // pointer magic. even though these are extracted, they just point to the
   // memory in the data frame
   Rcpp::CharacterVector zz_row_r = Rcpp::as<Rcpp::CharacterVector>(zz["row_r"]);
+  Rcpp::CharacterVector zz_c_cm  = Rcpp::as<Rcpp::CharacterVector>(zz["c_cm"]);
   Rcpp::CharacterVector zz_c_r   = Rcpp::as<Rcpp::CharacterVector>(zz["c_r"]);
   Rcpp::CharacterVector zz_v     = Rcpp::as<Rcpp::CharacterVector>(zz["v"]);
   Rcpp::CharacterVector zz_c_s   = Rcpp::as<Rcpp::CharacterVector>(zz["c_s"]);
@@ -358,6 +374,7 @@ void wide_to_long(
       case percentage:
       case scientific:
       case comma:
+      case hms_time:
       case numeric:
         cell.v   = vals;
         break;
@@ -391,8 +408,14 @@ void wide_to_long(
         cell.f   = vals;
         break;
       case array_formula:
-        cell.f   = vals;
-        cell.f_t = "array";
+        cell.f     = vals;
+        cell.f_t   = "array";
+        cell.f_ref = ref[i];
+        break;
+      case cm_formula:
+        cell.c_cm  = c_cm;
+        cell.f     = vals;
+        cell.f_t   = "array";
         cell.f_ref = ref[i];
         break;
       }
@@ -446,6 +469,7 @@ void wide_to_long(
       zz_row_r[pos] = row;
       zz_c_r[pos]   = col;
       if (!cell.v.empty())     zz_v[pos]     = cell.v;
+      if (!cell.c_cm.empty())  zz_c_cm[pos]  = cell.c_cm;
       if (!cell.c_s.empty())   zz_c_s[pos]   = cell.c_s;
       if (!cell.c_t.empty())   zz_c_t[pos]   = cell.c_t;
       if (!cell.is.empty())    zz_is[pos]    = cell.is;
