@@ -133,9 +133,6 @@ test_that("write xlsx", {
   expect_silent(write_xlsx(df, tmp, row.names = TRUE))
   expect_error(write_xlsx(df, tmp, rowNames = "NO"))
   expect_silent(write_xlsx(df, tmp, rowNames = TRUE))
-  expect_error(write_xlsx(df, tmp, xy = "A2"))
-  expect_warning(write_xlsx(df, tmp, xy = c(1, 2)))
-  expect_warning(write_xlsx(df, tmp, xy = c(1, 2)))
   expect_silent(write_xlsx(df, tmp, colWidth = "auto"))
   expect_silent(write_xlsx(list(df, df), tmp, firstActiveCol = 2, firstActiveRow = 2))
   expect_silent(write_xlsx(list(df, df), tmp, firstCol = FALSE, firstRow = FALSE))
