@@ -113,3 +113,48 @@ test_that("as_xml_attr works", {
   expect_equal(exp, mm)
 
 })
+
+test_that("string formating", {
+
+  foo <- fmt_txt("foo: ", bold = TRUE, size = 16, color = wb_color("green"))
+  bar <- fmt_txt("bar", underline = TRUE)
+  txt <- paste0(foo, bar)
+
+  exp <- "<is><r><rPr><b/><sz val=\"16\"/><color rgb=\"FF00FF00\"/></rPr><t xml:space=\"preserve\">foo: </t></r></is>"
+  got <- txt_to_is(foo)
+  expect_equal(exp, got)
+
+  exp <- "<si><r><rPr><b/><sz val=\"16\"/><color rgb=\"FF00FF00\"/></rPr><t xml:space=\"preserve\">foo: </t></r></si>"
+  got <- txt_to_si(foo)
+  expect_equal(exp, got)
+
+  wb <- wb_workbook()$add_worksheet()$add_data(x = data.frame(txt))
+
+  exp <- "foo: bar"
+  got <- wb_to_df(wb)$txt
+  expect_equal(exp, got)
+
+})
+
+test_that("outdec = \",\" works", {
+
+  options(OutDec = ",")
+
+  exp <- "[1] 1,1"
+  got <- capture.output(print(1.1))
+  expect_equal(exp, got)
+
+  wb <- wb_workbook()$add_worksheet()$set_col_widths(
+    cols = c(1, 4, 6, 7, 9),
+    widths = c(16, 15, 12, 18, 33)
+  )
+
+  exp <- c("16.711", "8.43", "15.711", "8.43", "12.711", "18.711", "8.43", "33.711")
+  got <- rbindlist(xml_attr(wb$worksheets[[1]]$cols_attr, "col"))$width
+  expect_equal(exp, got)
+
+  exp <- "[1] 1,1"
+  got <- capture.output(print(1.1))
+  expect_equal(exp, got)
+
+})
